import { Meta } from "@storybook/addon-docs";

<Meta title="Introduction/Introduction" />

# TRUMPF Integration Web Styleguide

This is the Storybook for the integration of specific features into Website and Shop. We offer multiple methods to integrate this bundle into your application:

## Integration via CDN

This bundle is available via our CDN. You can use the bundle directly from our CDN in your application. The version number needs to be defined in the URL. All available versions are listed here: https://cdn.trumpf.com/ux.integration-web-styleguide/

### Add CSS

```
<link rel="stylesheet" type="text/css" href="https://cdn.trumpf.com/ux.integration-web-styleguide/<version>/dist/ux-iws/ux-iws.css" media="all">
```

### Add JS

The browser picks the correct script via the [Module Fallback](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script#module_fallback).

If your application also uses requireJS, the this bundle needs to be added before requireJS.

```
<script type="module" src="https://cdn.trumpf.com/ux.integration-web-styleguide/<version>/dist/ux-iws/ux-iws.esm.js" crossorigin="anonymous"></script>
<script nomodule="" src="https://cdn.trumpf.com/ux.integration-web-styleguide/<version>/dist/ux-iws/ux-iws.js" crossorigin="anonymous"></script>
```

### Use the components

Components do not need any initialization.

```
<ux-iws-search-bar placeholder="test"></ux-iws-search-bar>
```

## Integration via npm

This bundle is available via npm.

### Setup npm to access the registry

Create a .npmrc file with the following content depending on your network configruation.

#### a) Onprem JFrog:

```
@trumpf:registry=https://srv01af2.corp.trumpf.com/artifactory/api/npm/trumpf.ux.npm/
//srv01af2.corp.trumpf.com/artifactory/api/npm/trumpf.ux.npm/:strict-ssl=false
strict-ssl=false
```

#### b) Cloud JFrog (trumpf.jfrog.io)

```
@trumpf:registry=https://trumpf.jfrog.io/artifactory/api/npm/trumpf-npm-virtual/
```

Login to the registry:

```
npm login --scope=trumpf --registry=https://trumpf.jfrog.io/artifactory/api/npm/trumpf-npm-virtual/
```

### Install the package

This installs the latest stable version.

```
npm install @trumpf/ux.integration-web-styleguide
```

#### Unstable releases (preview branches)

For every commit on preview branches we automatically release an unstable package that can be used to test the latest changes in your application. You can install them as follows (the exact tag can be found in the tags on gitlab):

```
npm install @trumpf/ux.integration-web-styleguide@1.2.3-preview-my-feature.1
```

## Other Storybooks

### ux.ui Design System

<a href="https://docs.ux.trumpf.com/uxuicore/main/" target="_blank">
    https://docs.ux.trumpf.com/uxuicore/main/
</a>

### ux.ui Widgets

<a href="https://docs.ux.trumpf.com/uxcorewidgets/main/" target="_blank">
    https://docs.ux.trumpf.com/uxcorewidgets/main/
</a>

### ux.ui Community Design System

<a href="https://docs.ux.trumpf.com/uxuicommunity/main/" target="_blank">
    https://docs.ux.trumpf.com/uxuicommunity/main/
</a>

## Frequently asked questions

<ux-accordion>
    <div slot="title">Addons panel is not displayed</div>
    <div class="ux-text-normal ux-text-normal--light-gray">
        It should be possible to show/hide the addons panel by pressing the
        "alt" + "a" key. Pressing the "alt" + "d" key is the shortcut for
        changing the addons panel placement. Both actions can also be triggered
        from the storybook menu (the ellipsis right to the TRUMPF logo).
        Sometimes the addon panel gets hidden based on local storage (Storybook
        stores the opened/closed status for the addons in the localStorage). In
        that case, running localStorage.clear() in the browser console and
        hard-reloading the page should fix it.
    </div>
</ux-accordion>
